@@ -44,7 +44,7 @@ from nucliadb_utils.cache.settings import settings as cache_settings
 
 images.settings["nucliadb_node_reader"] = {
     "image": "eu.gcr.io/stashify-218417/node",
-    "version": "main",
+    "version": "latest",
     "env": {
         "NUCLIADB_DISABLE_ANALYTICS": "True",
         "DATA_PATH": "/data",
@@ -59,15 +59,14 @@ images.settings["nucliadb_node_reader"] = {
             "/usr/local/bin/node_reader",
         ],
         "platform": "linux/amd64",
-        "mem_limit": "2g",
+        "mem_limit": "3g",
         "ports": {"4445": None},
-        "mem_limit": "2g",  # default is 1g, need to override
     },
 }
 
 images.settings["nucliadb_node_writer"] = {
     "image": "eu.gcr.io/stashify-218417/node",
-    "version": "main",
+    "version": "latest",
     "env": {
         "NUCLIADB_DISABLE_ANALYTICS": "True",
         "DATA_PATH": "/data",
@@ -81,9 +80,8 @@ images.settings["nucliadb_node_writer"] = {
             "/usr/local/bin/node_writer",
         ],
         "platform": "linux/amd64",
-        "mem_limit": "2g",
+        "mem_limit": "3g",
         "ports": {"4446": None},
-        "mem_limit": "2g",  # default is 1g, need to override
     },
 }
 
