@@ -105,6 +105,26 @@ pub fn read_or_create_host_key(hk_path: PathBuf) -> NodeResult<Uuid> {
     Ok(host_key)
 }
 
+pub fn set_primary_node_id(data_path: PathBuf, primary_id: String) -> NodeResult<()> {
+    let filepath = data_path.join("primary_id");
+
+    fs::write(filepath.clone(), primary_id)
+        .with_context(|| format!("Failed to write primary ID to '{}'", filepath.display()))?;
+
+    Ok(())
+}
+
+pub fn get_primary_node_id(data_path: PathBuf) -> Option<String> {
+    let filepath = data_path.join("primary_id");
+    let read_result = fs::read(filepath.clone());
+    if read_result.is_err() {
+        return None;
+    }
+    read_result
+        .map(|bytes| String::from_utf8(bytes).unwrap())
+        .ok()
+}
+
 pub fn parse_node_role(role: &str) -> NodeRole {
     match role {
         "primary" => NodeRole::Primary,
@@ -132,6 +152,9 @@ pub async fn list_shards(shards_path: PathBuf) -> Vec<String> {
 
 #[cfg(test)]
 mod tests {
+    use serial_test::serial;
+    use tempfile::TempDir;
+
     use super::*;
 
     #[test]
@@ -162,4 +185,16 @@ mod tests {
         matches!(parse_node_role("primary"), NodeRole::Primary);
         matches!(parse_node_role("secondary"), NodeRole::Secondary);
     }
+
+    #[test]
+    #[serial]
+    fn test_set_primary_id() {
+        let tempdir = TempDir::new().expect("Unable to create temporary data directory");
+        let tempdir_path = tempdir.into_path();
+        // set env variable
+        let primary_id = "test_primary_id".to_string();
+        set_primary_node_id(tempdir_path.clone(), primary_id.clone()).unwrap();
+        let read_primary_id = get_primary_node_id(tempdir_path).unwrap();
+        assert_eq!(primary_id, read_primary_id);
+    }
 }
